/* ui.h - header file for user interface
 * $Id: ui.h,v 1.5 2005/05/08 23:51:41 knilch Exp $ */

/* Ramdefrag User Interface Abstraction Layer
 *  (c) 2004, 2005 Tobias 'knilch' Jordan <knilch@users.sourceforge.net>
 *
 *  Setting Orange, the 50th day of Chaos in the YOLD 3170
 *  (Celebrate Chaoflux!)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 *                            SUSPENDED ANNIHILATION
 */
#ifndef UI_H
#define UI_H

/*                               IMPENDING  DOOM
 *                                 HAS ARRIVED
 *      And Five Days Prior to This Occasion The Apostle The Elder
 *      Malaclypse Shall Walk the Streets of Whittier Bearing a Sign
 *      for All Literates to Read thereof: "DOOM", as a Warning of
 *      Forthcoming Doom to All Men Impending. And He Shall Signal
 *      This Event by Seeking the Poor and Distributing to Them Precious
 *      MAO BUTTONS and Whittier Shall be Known as The Region of Thud
 *      for These Five Days.
 */

int gtk_ui(int argc, char *argv[]);

int cl_ui(int argc, char *argv[]);

#endif /* UI_H */
