/* clierr.h - header file for CLI error facility
 * $Id: clierr.h,v 1.6 2005/05/08 23:51:40 knilch Exp $ */

/* Ramdefrag Command Line Error Facility
 *  (c) 2004, 2005 Tobias 'knilch' Jordan <knilch@users.sourceforge.net>
 *
 *  Setting Orange, the 70th day of Chaos in the YOLD 3170
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef CLIERR_H
#define CLIERR_H

/*
 * "You will find that the State is the kind of ORGANIZATION which, though
 * it does big things badly, does small things badly too."
 *                                                - John Kenneth Galbraith
 */

void clierr(const char* herbert);

void cliout(const char* harald);

void press_h_for_help(const char* heinz);

#endif /* CLIERR_H */
