/* dstates.h - header file for defrag states
 * $Id: dstates.h,v 1.7 2005/05/08 23:51:40 knilch Exp $ */

/* Ramdefrag Defragmentation State Handling
 *  (c) 2004, 2005 Tobias 'knilch' Jordan <knilch@users.sourceforge.net>
 *
 *  Boomtime, the 42nd day of Chaos in the YOLD 3170
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software Foundation,
 *  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef DSTATES_H
#define DSTATES_H

#define STAT_MAX 4096

char* getphase(int phaseid);

char* getstatus(int phaseid, char *buf, int mr);

char* analyze(char *buf, int mr);

#endif /* DSTATES_H */
