#define MainForm 1000
#define MainMenu 1001
#define MainBttn 2000
#define MainCBSt 2100
#define MainCBOp 2101
#define MainMIAb 2300
#define AboutAlert 3000
#define CongratAlert 3001
#define TmpErrorAlert 3002
#define PrmErrorAlert 3003
#define MainHelp 1000
#define AlertHelp 1001
#define CongratHelp 1002
#define TmpErrorHelp 1003
#define PrmErrorHelp 1004
#define CvsID 2000
