/* horsti.h - header file for H.O.R.S.T.I.
 * $Id: horsti.h,v 1.4 2005/05/08 23:51:41 knilch Exp $ */

/* H.O.R.S.T.I. - Hybrid Operating Random System Transition Interface
 *  (c) 2004, 2005 Tobias 'knilch' Jordan <knilch@users.sourceforge.net>
 *
 *  Sweetmorn, the 11th day of Chaos in the YOLD 3170
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef HORSTI_H
#define HORSTI_H

int enable_horsti(int msglev, int enable);

void disable_horsti(int msglev, int enabled);

#endif /* HORSTI_H */
