/* msgs.h - header file with message declarations
 * $Id: msgs.h,v 1.5 2005/05/08 23:51:41 knilch Exp $ */

/* Some Standard Messages for Ramdefrag
 *  (c) 2004, 2005 Tobias 'knilch' Jordan <knilch@users.sourceforge.net>
 *
 *  Boomtime, the 42nd day of Chaos in the YOLD 3170
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software Foundation,
 *  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MSGS_H
#define MSGS_H

#include "support.h" /* for gettext-#defines */

/*
 *                   THE BATTLE HYMN OF THE ERISTOCRACY
 *                              by Lord Omar
 */
#define ST_DEFRAG_DONE _("Defragmentation successful.\n")
/*
 * VERSE
 * Mine brain has meditated on the spinning of The Chao;
 * It is hovering o'er the table where the Chiefs of Staff are now
 * Gathered in discussion of the dropping of The Bomb;
 * Her Apple Corps is strong!
 */
#define ST_DEFRAG_ABORTED _("Cancelled.\nWARNING: system probably unstable, do RAM defragmentation!\n")
/*
 * CHORUS
 * Grand (and gory) Old Discordja!
 * Grand (and gory) Old Discordja!
 * Grand (and gory) Old Discordja!
 * Her Apple Corps is strong!
 */
#define ST_PROGRAM_QUIT _("Congratulations. Your RAM was defragmented perfectly.\n")

/*
 * VERSE
 * She was not invited to the party that they held on Limbo Peak;*
 * So She threw a Golden Apple, 'sted of turn'd t'other cheek!
 * O it cracked the Holy Punchbowl and it made the nectar leak;
 * Her Apple Corps is strong!
 *
 *
 * * "Limbo Peak" refers to Old Limbo Peak, commonly called by the Greeks
 *   "Ol' Limb' Peak."
 *
 */

static char Personal[]= "\n"
       " PLANETARY  PI,  which  I  discovered,\n"
       "is 61. It's a Time-Energy relationship\n"
       "existing between  sun and inner plants\n"
       "and I use it in arriving at many facts\n"
       "unknown   to  science.   For  Example,\n"
       "multiply  nude  earth's  circumference\n"
       "24,902.20656  by  61  and  you get the\n"
       "distance of  moon's  orbit  around the\n"
       "earth.  This  is  slightly  less  than\n"
       "actual distance  because  we have  not\n"
       "yet considered earth's atmosphere.  So\n"
       "be it.  Christopher Garth, Evanston.\n";

#endif /* MSGS_H */
