/* callbacks.h - header file for gtk gui callbacks
 * $Id: callbacks.h,v 1.5 2005/05/08 23:45:40 knilch Exp $ */

/* Ramdefrag GTK User Interface Callback Functions
 *  (c) 2004, 2005 Tobias 'knilch' Jordan <knilch@users.sourceforge.net>
 *
 *  Setting Orange, the 70th day of Chaos in the YOLD 3170
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 *           A POEE MYSTEREE RITE - THE SRI SYADASTIAN CHANT
 *                  Written, in some sense, by Mal-2
 */

#ifndef CALLBACKS_H
#define CALLBACKS_H

/* Unlike a song, chants are not sung but chanted. This particular one is *
 * much enhanced by the use of a Leader to chant the Sanskrit alone, with *
 * all participants chanting the English. It also behooves one to be in a *
 * quiet frame of mind and to be sitting in a still position, perhaps The *
 * Buttercup Position. It also helps if one is absolutely zonked out of   *
 * his gourd.                                                             */

#include <gtk/gtk.h>

/*
 * RUB-A-DUB-DUB
 * O! Hail Eris. Blessed St. Hung Mung.
 * SYA-DASTI
 * O! Hail Eris. Blessed St. Mo-jo.
 */

void on_startbtn_clicked(GtkButton *button, gpointer user_data);

/*
 * SYA-DAVAK-TAVYA
 * O! Hail Eris. Blessed St. Zara-thud.
 * SYA-DASTI SYA-NASTI
 * O! Hail Eris. Blessed St. Elder Mal.
 */


void on_cancelbtn_clicked(GtkButton *button, gpointer user_data);

/*
 * SYA-DASTI KAVAK-TAV-YASKA
 * O! Hail Eris. Blessed St. Gu-lik.
 * SYA-DASTI, SYA-NASTI, SYA-DAVAK-TAV-YASKA
 * O! Hail Eris. All Hail Dis-cord-ia.
 * RUB-A-DUB-DUB
 */

void on_okbutton_clicked(GtkButton *button, gpointer user_data);

/* It is then repeated indefinitely, or for the first two thousand miles, *
 * which ever comes first.                                                */

#endif /* CALLBACKS_H */

